@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2005 Roger While
+ * Copyright (C) 2004-2007 Roger While
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -13,11 +13,12 @@
  * 
  * You should have received a copy of the GNU General Public License 
  * along with this software; see the file COPYING.  If not, write to
- * the Free Software Foundation, Inc., 59 Temple Place, Suite 330,
- * Boston, MA 02111-1307 USA
+ * the Free Software Foundation, 51 Franklin Street, Fifth Floor
+ * Boston, MA 02110-1301 USA
  */
 
 #include	<stdio.h>
+#include	<string.h>
 #include	<libcob.h>
 
 int
@@ -26,7 +27,11 @@ main (int argc, char **argv)
 	int (*func)();
 
 	if ( argc <= 1 ) {
-		fprintf(stderr, "Number of parameters incorrect\n");
+		fprintf(stderr, "Usage: cobcrun PROGRAM [param ...]\n");
+		return 1;
+	}
+	if (strlen (argv[1]) > 32) {
+		fprintf(stderr, "Invalid PROGRAM name\n");
 		return 1;
 	}
 	cob_init (argc - 1, &argv[1]);
@@ -34,5 +39,5 @@ main (int argc, char **argv)
 	if (func == NULL) {
 		cob_call_error ();
 	}
-	return func();
+	cob_stop_run ( func() );
 }
