@@ -1,7 +1,7 @@
-/* A Bison parser, made by GNU Bison 2.0.  */
+/* A Bison parser, made by GNU Bison 1.875.  */
 
 /* Skeleton parser for Yacc-like parsing with Bison,
-   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004 Free Software Foundation, Inc.
+   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -45,7 +45,8 @@
 /* Using locations.  */
 #define YYLSP_NEEDED 0
 
-/* Substitute the variable and function names.  */
+/* If NAME_PREFIX is specified substitute the variables and functions
+   names.  */
 #define yyparse ppparse
 #define yylex   pplex
 #define yyerror pperror
@@ -102,7 +103,7 @@
 
 
 /* Copy the first part of user declarations.  */
-#line 25 "ppparse.y"
+#line 26 "ppparse.y"
 
 #include "config.h"
 
@@ -134,13 +135,13 @@ static struct cb_replace_list *cb_replace_list_add (struct cb_replace_list *repl
 #endif
 
 #if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
-#line 42 "ppparse.y"
+#line 43 "ppparse.y"
 typedef union YYSTYPE {
-  char *s;
-  struct cb_text_list *l;
-  struct cb_replace_list *r;
+	char			*s;
+	struct cb_text_list	*l;
+	struct cb_replace_list	*r;
 } YYSTYPE;
-/* Line 190 of yacc.c.  */
+/* Line 191 of yacc.c.  */
 #line 145 "ppparse.c"
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
@@ -152,26 +153,23 @@ typedef union YYSTYPE {
 /* Copy the second part of user declarations.  */
 
 
-/* Line 213 of yacc.c.  */
+/* Line 214 of yacc.c.  */
 #line 157 "ppparse.c"
 
 #if ! defined (yyoverflow) || YYERROR_VERBOSE
 
-# ifndef YYFREE
-#  define YYFREE free
-# endif
-# ifndef YYMALLOC
-#  define YYMALLOC malloc
-# endif
-
 /* The parser invokes alloca or malloc; define the necessary symbols.  */
 
-# ifdef YYSTACK_USE_ALLOCA
-#  if YYSTACK_USE_ALLOCA
-#   ifdef __GNUC__
-#    define YYSTACK_ALLOC __builtin_alloca
-#   else
+# if YYSTACK_USE_ALLOCA
+#  define YYSTACK_ALLOC alloca
+# else
+#  ifndef YYSTACK_USE_ALLOCA
+#   if defined (alloca) || defined (_ALLOCA_H)
 #    define YYSTACK_ALLOC alloca
+#   else
+#    ifdef __GNUC__
+#     define YYSTACK_ALLOC __builtin_alloca
+#    endif
 #   endif
 #  endif
 # endif
@@ -184,20 +182,20 @@ typedef union YYSTYPE {
 #   include <stdlib.h> /* INFRINGES ON USER NAME SPACE */
 #   define YYSIZE_T size_t
 #  endif
-#  define YYSTACK_ALLOC YYMALLOC
-#  define YYSTACK_FREE YYFREE
+#  define YYSTACK_ALLOC malloc
+#  define YYSTACK_FREE free
 # endif
 #endif /* ! defined (yyoverflow) || YYERROR_VERBOSE */
 
 
 #if (! defined (yyoverflow) \
      && (! defined (__cplusplus) \
-	 || (defined (YYSTYPE_IS_TRIVIAL) && YYSTYPE_IS_TRIVIAL)))
+	 || (YYSTYPE_IS_TRIVIAL)))
 
 /* A type that is properly aligned for any stack member.  */
 union yyalloc
 {
-  short int yyss;
+  short yyss;
   YYSTYPE yyvs;
   };
 
@@ -207,13 +205,13 @@ union yyalloc
 /* The size of an array large to enough to hold all stacks, each with
    N elements.  */
 # define YYSTACK_BYTES(N) \
-     ((N) * (sizeof (short int) + sizeof (YYSTYPE))			\
+     ((N) * (sizeof (short) + sizeof (YYSTYPE))				\
       + YYSTACK_GAP_MAXIMUM)
 
 /* Copy COUNT objects from FROM to TO.  The source and destination do
    not overlap.  */
 # ifndef YYCOPY
-#  if defined (__GNUC__) && 1 < __GNUC__
+#  if 1 < __GNUC__
 #   define YYCOPY(To, From, Count) \
       __builtin_memcpy (To, From, (Count) * sizeof (*(From)))
 #  else
@@ -249,7 +247,7 @@ union yyalloc
 #if defined (__STDC__) || defined (__cplusplus)
    typedef signed char yysigned_char;
 #else
-   typedef short int yysigned_char;
+   typedef short yysigned_char;
 #endif
 
 /* YYFINAL -- State number of the termination state. */
@@ -337,11 +335,11 @@ static const yysigned_char yyrhs[] =
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
 static const unsigned char yyrline[] =
 {
-       0,    57,    57,    57,    58,    58,    58,    61,    65,    68,
-      69,    73,    83,    84,    85,    87,    88,    91,    92,    95,
-      96,    99,   100,   103,   104,   107,   108,   111,   112,   115,
-     116,   123,   130,   141,   142,   148,   148,   149,   149,   150,
-     150
+       0,    58,    58,    58,    59,    59,    59,    62,    66,    70,
+      71,    75,    87,    88,    89,    92,    93,    97,    98,   102,
+     103,   107,   108,   112,   113,   117,   118,   122,   123,   127,
+     128,   135,   142,   155,   156,   163,   163,   164,   164,   165,
+     165
 };
 #endif
 
@@ -350,20 +348,21 @@ static const unsigned char yyrline[] =
    First, the terminals, then, starting at YYNTOKENS, nonterminals. */
 static const char *const yytname[] =
 {
-  "$end", "error", "$undefined", "DIRECTIVE", "SOURCE", "FORMAT", "IS",
-  "FIXED", "FREE", "COPY", "REPLACE", "SUPPRESS", "PRINTING", "REPLACING",
-  "OFF", "IN", "OF", "BY", "EQEQ", "TOKEN", "'.'", "'('", "')'", "$accept",
-  "statement_list", "statement", "directive", "source_format", "format",
-  "copy_statement", "copy_in", "copy_suppress", "copy_replacing",
-  "replace_statement", "replacing_list", "text", "pseudo_text",
-  "token_list", "identifier", "subscripts", "_format", "_is", "_printing", 0
+  "$end", "error", "$undefined", "DIRECTIVE", "SOURCE", "FORMAT", "IS", 
+  "FIXED", "FREE", "COPY", "REPLACE", "SUPPRESS", "PRINTING", "REPLACING", 
+  "OFF", "IN", "OF", "BY", "EQEQ", "TOKEN", "'.'", "'('", "')'", 
+  "$accept", "statement_list", "statement", "directive", "source_format", 
+  "format", "copy_statement", "copy_in", "copy_suppress", 
+  "copy_replacing", "replace_statement", "replacing_list", "text", 
+  "pseudo_text", "token_list", "identifier", "subscripts", "_format", 
+  "_is", "_printing", 0
 };
 #endif
 
 # ifdef YYPRINT
 /* YYTOKNUM[YYLEX-NUM] -- Internal token number corresponding to
    token YYLEX-NUM.  */
-static const unsigned short int yytoknum[] =
+static const unsigned short yytoknum[] =
 {
        0,   256,   257,   258,   259,   260,   261,   262,   263,   264,
      265,   266,   267,   268,   269,   270,   271,   272,   273,   274,
@@ -492,8 +491,7 @@ static const unsigned char yystos[] =
 
 #define YYACCEPT	goto yyacceptlab
 #define YYABORT		goto yyabortlab
-#define YYERROR		goto yyerrorlab
-
+#define YYERROR		goto yyerrlab1
 
 /* Like YYERROR except do call yyerror.  This remains here temporarily
    to ease the transition to the new meaning of YYERROR, for GCC.
@@ -520,53 +518,20 @@ do								\
     }								\
 while (0)
 
-
 #define YYTERROR	1
 #define YYERRCODE	256
 
+/* YYLLOC_DEFAULT -- Compute the default location (before the actions
+   are run).  */
 
-/* YYLLOC_DEFAULT -- Set CURRENT to span from RHS[1] to RHS[N].
-   If N is 0, then set CURRENT to the empty location which ends
-   the previous symbol: RHS[0] (always defined).  */
-
-#define YYRHSLOC(Rhs, K) ((Rhs)[K])
 #ifndef YYLLOC_DEFAULT
-# define YYLLOC_DEFAULT(Current, Rhs, N)				\
-    do									\
-      if (N)								\
-	{								\
-	  (Current).first_line   = YYRHSLOC (Rhs, 1).first_line;	\
-	  (Current).first_column = YYRHSLOC (Rhs, 1).first_column;	\
-	  (Current).last_line    = YYRHSLOC (Rhs, N).last_line;		\
-	  (Current).last_column  = YYRHSLOC (Rhs, N).last_column;	\
-	}								\
-      else								\
-	{								\
-	  (Current).first_line   = (Current).last_line   =		\
-	    YYRHSLOC (Rhs, 0).last_line;				\
-	  (Current).first_column = (Current).last_column =		\
-	    YYRHSLOC (Rhs, 0).last_column;				\
-	}								\
-    while (0)
+# define YYLLOC_DEFAULT(Current, Rhs, N)         \
+  Current.first_line   = Rhs[1].first_line;      \
+  Current.first_column = Rhs[1].first_column;    \
+  Current.last_line    = Rhs[N].last_line;       \
+  Current.last_column  = Rhs[N].last_column;
 #endif
 
-
-/* YY_LOCATION_PRINT -- Print the location on the stream.
-   This macro was not mandated originally: define only if we know
-   we won't break user code: when these are the locations we know.  */
-
-#ifndef YY_LOCATION_PRINT
-# if YYLTYPE_IS_TRIVIAL
-#  define YY_LOCATION_PRINT(File, Loc)			\
-     fprintf (File, "%d.%d-%d.%d",			\
-              (Loc).first_line, (Loc).first_column,	\
-              (Loc).last_line,  (Loc).last_column)
-# else
-#  define YY_LOCATION_PRINT(File, Loc) ((void) 0)
-# endif
-#endif
-
-
 /* YYLEX -- calling `yylex' with the right arguments.  */
 
 #ifdef YYLEX_PARAM
@@ -589,30 +554,36 @@ do {						\
     YYFPRINTF Args;				\
 } while (0)
 
-# define YY_SYMBOL_PRINT(Title, Type, Value, Location)		\
+# define YYDSYMPRINT(Args)			\
+do {						\
+  if (yydebug)					\
+    yysymprint Args;				\
+} while (0)
+
+# define YYDSYMPRINTF(Title, Token, Value, Location)		\
 do {								\
   if (yydebug)							\
     {								\
       YYFPRINTF (stderr, "%s ", Title);				\
       yysymprint (stderr, 					\
-                  Type, Value);	\
+                  Token, Value);	\
       YYFPRINTF (stderr, "\n");					\
     }								\
 } while (0)
 
 /*------------------------------------------------------------------.
 | yy_stack_print -- Print the state stack from its BOTTOM up to its |
-| TOP (included).                                                   |
+| TOP (cinluded).                                                   |
 `------------------------------------------------------------------*/
 
 #if defined (__STDC__) || defined (__cplusplus)
 static void
-yy_stack_print (short int *bottom, short int *top)
+yy_stack_print (short *bottom, short *top)
 #else
 static void
 yy_stack_print (bottom, top)
-    short int *bottom;
-    short int *top;
+    short *bottom;
+    short *top;
 #endif
 {
   YYFPRINTF (stderr, "Stack now");
@@ -642,9 +613,9 @@ yy_reduce_print (yyrule)
 #endif
 {
   int yyi;
-  unsigned int yylno = yyrline[yyrule];
+  unsigned int yylineno = yyrline[yyrule];
   YYFPRINTF (stderr, "Reducing stack by rule %d (line %u), ",
-             yyrule - 1, yylno);
+             yyrule - 1, yylineno);
   /* Print the symbols being reduced, and their result.  */
   for (yyi = yyprhs[yyrule]; 0 <= yyrhs[yyi]; yyi++)
     YYFPRINTF (stderr, "%s ", yytname [yyrhs[yyi]]);
@@ -662,7 +633,8 @@ do {					\
 int yydebug;
 #else /* !YYDEBUG */
 # define YYDPRINTF(Args)
-# define YY_SYMBOL_PRINT(Title, Type, Value, Location)
+# define YYDSYMPRINT(Args)
+# define YYDSYMPRINTF(Title, Token, Value, Location)
 # define YY_STACK_PRINT(Bottom, Top)
 # define YY_REDUCE_PRINT(Rule)
 #endif /* !YYDEBUG */
@@ -680,6 +652,10 @@ int yydebug;
    SIZE_MAX < YYSTACK_BYTES (YYMAXDEPTH)
    evaluated with infinite-precision integer arithmetic.  */
 
+#if YYMAXDEPTH == 0
+# undef YYMAXDEPTH
+#endif
+
 #ifndef YYMAXDEPTH
 # define YYMAXDEPTH 10000
 #endif
@@ -761,15 +737,15 @@ yysymprint (yyoutput, yytype, yyvaluep)
   (void) yyvaluep;
 
   if (yytype < YYNTOKENS)
-    YYFPRINTF (yyoutput, "token %s (", yytname[yytype]);
+    {
+      YYFPRINTF (yyoutput, "token %s (", yytname[yytype]);
+# ifdef YYPRINT
+      YYPRINT (yyoutput, yytoknum[yytype], *yyvaluep);
+# endif
+    }
   else
     YYFPRINTF (yyoutput, "nterm %s (", yytname[yytype]);
 
-
-# ifdef YYPRINT
-  if (yytype < YYNTOKENS)
-    YYPRINT (yyoutput, yytoknum[yytype], *yyvaluep);
-# endif
   switch (yytype)
     {
       default:
@@ -785,11 +761,10 @@ yysymprint (yyoutput, yytype, yyvaluep)
 
 #if defined (__STDC__) || defined (__cplusplus)
 static void
-yydestruct (const char *yymsg, int yytype, YYSTYPE *yyvaluep)
+yydestruct (int yytype, YYSTYPE *yyvaluep)
 #else
 static void
-yydestruct (yymsg, yytype, yyvaluep)
-    const char *yymsg;
+yydestruct (yytype, yyvaluep)
     int yytype;
     YYSTYPE *yyvaluep;
 #endif
@@ -797,10 +772,6 @@ yydestruct (yymsg, yytype, yyvaluep)
   /* Pacify ``unused variable'' warnings.  */
   (void) yyvaluep;
 
-  if (!yymsg)
-    yymsg = "Deleting";
-  YY_SYMBOL_PRINT (yymsg, yytype, yyvaluep, yylocationp);
-
   switch (yytype)
     {
 
@@ -828,10 +799,10 @@ int yyparse ();
 
 
 
-/* The look-ahead symbol.  */
+/* The lookahead symbol.  */
 int yychar;
 
-/* The semantic value of the look-ahead symbol.  */
+/* The semantic value of the lookahead symbol.  */
 YYSTYPE yylval;
 
 /* Number of syntax errors so far.  */
@@ -867,7 +838,7 @@ yyparse ()
   int yyresult;
   /* Number of tokens to shift before error messages enabled.  */
   int yyerrstatus;
-  /* Look-ahead token as an internal (translated) token number.  */
+  /* Lookahead token as an internal (translated) token number.  */
   int yytoken = 0;
 
   /* Three stacks and their tools:
@@ -879,9 +850,9 @@ yyparse ()
      to reallocate them elsewhere.  */
 
   /* The state stack.  */
-  short int yyssa[YYINITDEPTH];
-  short int *yyss = yyssa;
-  register short int *yyssp;
+  short	yyssa[YYINITDEPTH];
+  short *yyss = yyssa;
+  register short *yyssp;
 
   /* The semantic value stack.  */
   YYSTYPE yyvsa[YYINITDEPTH];
@@ -918,9 +889,6 @@ yyparse ()
   yyssp = yyss;
   yyvsp = yyvs;
 
-
-  yyvsp[0] = yylval;
-
   goto yysetstate;
 
 /*------------------------------------------------------------.
@@ -946,7 +914,7 @@ yyparse ()
 	   these so that the &'s don't force the real ones into
 	   memory.  */
 	YYSTYPE *yyvs1 = yyvs;
-	short int *yyss1 = yyss;
+	short *yyss1 = yyss;
 
 
 	/* Each stack pointer address is followed by the size of the
@@ -974,7 +942,7 @@ yyparse ()
 	yystacksize = YYMAXDEPTH;
 
       {
-	short int *yyss1 = yyss;
+	short *yyss1 = yyss;
 	union yyalloc *yyptr =
 	  (union yyalloc *) YYSTACK_ALLOC (YYSTACK_BYTES (yystacksize));
 	if (! yyptr)
@@ -1010,18 +978,18 @@ yyparse ()
 yybackup:
 
 /* Do appropriate processing given the current state.  */
-/* Read a look-ahead token if we need one and don't already have one.  */
+/* Read a lookahead token if we need one and don't already have one.  */
 /* yyresume: */
 
-  /* First try to decide what to do without reference to look-ahead token.  */
+  /* First try to decide what to do without reference to lookahead token.  */
 
   yyn = yypact[yystate];
   if (yyn == YYPACT_NINF)
     goto yydefault;
 
-  /* Not known => get a look-ahead token if don't already have one.  */
+  /* Not known => get a lookahead token if don't already have one.  */
 
-  /* YYCHAR is either YYEMPTY or YYEOF or a valid look-ahead symbol.  */
+  /* YYCHAR is either YYEMPTY or YYEOF or a valid lookahead symbol.  */
   if (yychar == YYEMPTY)
     {
       YYDPRINTF ((stderr, "Reading a token: "));
@@ -1036,7 +1004,7 @@ yybackup:
   else
     {
       yytoken = YYTRANSLATE (yychar);
-      YY_SYMBOL_PRINT ("Next token is", yytoken, &yylval, &yylloc);
+      YYDSYMPRINTF ("Next token is", yytoken, &yylval, &yylloc);
     }
 
   /* If the proper action on seeing token YYTOKEN is to reduce or to
@@ -1056,8 +1024,8 @@ yybackup:
   if (yyn == YYFINAL)
     YYACCEPT;
 
-  /* Shift the look-ahead token.  */
-  YY_SYMBOL_PRINT ("Shifting", yytoken, &yylval, &yylloc);
+  /* Shift the lookahead token.  */
+  YYDPRINTF ((stderr, "Shifting token %s, ", yytname[yytoken]));
 
   /* Discard the token being shifted unless it is eof.  */
   if (yychar != YYEOF)
@@ -1107,156 +1075,158 @@ yyreduce:
   switch (yyn)
     {
         case 9:
-#line 68 "ppparse.y"
+#line 70 "ppparse.y"
     { cb_source_format = CB_FORMAT_FIXED; ;}
     break;
 
   case 10:
-#line 69 "ppparse.y"
+#line 71 "ppparse.y"
     { cb_source_format = CB_FORMAT_FREE; ;}
     break;
 
   case 11:
-#line 74 "ppparse.y"
+#line 76 "ppparse.y"
     {
-    fputc ('\n', ppout);
-    (yyvsp[-4].s) = fix_filename ((yyvsp[-4].s));
-    if ((yyvsp[-3].s))
-      (yyvsp[-3].s) = fix_filename ((yyvsp[-3].s));
-    ppcopy ((yyvsp[-4].s), (yyvsp[-3].s), (yyvsp[-1].r));
+	fputc ('\n', ppout);
+	yyvsp[-4].s = fix_filename (yyvsp[-4].s);
+	if (yyvsp[-3].s) {
+		yyvsp[-3].s = fix_filename (yyvsp[-3].s);
+	}
+	ppcopy (yyvsp[-4].s, yyvsp[-3].s, yyvsp[-1].r);
   ;}
     break;
 
   case 12:
-#line 83 "ppparse.y"
-    { (yyval.s) = NULL; ;}
+#line 87 "ppparse.y"
+    { yyval.s = NULL; ;}
     break;
 
   case 13:
-#line 84 "ppparse.y"
-    { (yyval.s) = (yyvsp[0].s); ;}
+#line 88 "ppparse.y"
+    { yyval.s = yyvsp[0].s; ;}
     break;
 
   case 14:
-#line 85 "ppparse.y"
-    { (yyval.s) = (yyvsp[0].s); ;}
+#line 89 "ppparse.y"
+    { yyval.s = yyvsp[0].s; ;}
     break;
 
   case 17:
-#line 91 "ppparse.y"
-    { (yyval.r) = NULL; ;}
+#line 97 "ppparse.y"
+    { yyval.r = NULL; ;}
     break;
 
   case 18:
-#line 92 "ppparse.y"
-    { (yyval.r) = (yyvsp[0].r); ;}
+#line 98 "ppparse.y"
+    { yyval.r = yyvsp[0].r; ;}
     break;
 
   case 19:
-#line 95 "ppparse.y"
-    { pp_set_replace_list ((yyvsp[-1].r)); ;}
+#line 102 "ppparse.y"
+    { pp_set_replace_list (yyvsp[-1].r); ;}
     break;
 
   case 20:
-#line 96 "ppparse.y"
+#line 103 "ppparse.y"
     { pp_set_replace_list (NULL); ;}
     break;
 
   case 21:
-#line 99 "ppparse.y"
-    { (yyval.r) = cb_replace_list_add (NULL, (yyvsp[-2].l), (yyvsp[0].l)); ;}
+#line 107 "ppparse.y"
+    { yyval.r = cb_replace_list_add (NULL, yyvsp[-2].l, yyvsp[0].l); ;}
     break;
 
   case 22:
-#line 100 "ppparse.y"
-    { (yyval.r) = cb_replace_list_add ((yyvsp[-3].r), (yyvsp[-2].l), (yyvsp[0].l)); ;}
+#line 108 "ppparse.y"
+    { yyval.r = cb_replace_list_add (yyvsp[-3].r, yyvsp[-2].l, yyvsp[0].l); ;}
     break;
 
   case 23:
-#line 103 "ppparse.y"
-    { (yyval.l) = (yyvsp[0].l); ;}
+#line 112 "ppparse.y"
+    { yyval.l = yyvsp[0].l; ;}
     break;
 
   case 24:
-#line 104 "ppparse.y"
-    { (yyval.l) = (yyvsp[0].l); ;}
+#line 113 "ppparse.y"
+    { yyval.l = yyvsp[0].l; ;}
     break;
 
   case 25:
-#line 107 "ppparse.y"
-    { (yyval.l) = NULL; ;}
+#line 117 "ppparse.y"
+    { yyval.l = NULL; ;}
     break;
 
   case 26:
-#line 108 "ppparse.y"
-    { (yyval.l) = (yyvsp[-1].l); ;}
+#line 118 "ppparse.y"
+    { yyval.l = yyvsp[-1].l; ;}
     break;
 
   case 27:
-#line 111 "ppparse.y"
-    { (yyval.l) = cb_text_list_add (NULL, (yyvsp[0].s)); ;}
+#line 122 "ppparse.y"
+    { yyval.l = cb_text_list_add (NULL, yyvsp[0].s); ;}
     break;
 
   case 28:
-#line 112 "ppparse.y"
-    { (yyval.l) = cb_text_list_add ((yyvsp[-1].l), (yyvsp[0].s)); ;}
+#line 123 "ppparse.y"
+    { yyval.l = cb_text_list_add (yyvsp[-1].l, yyvsp[0].s); ;}
     break;
 
   case 29:
-#line 115 "ppparse.y"
-    { (yyval.l) = cb_text_list_add (NULL, (yyvsp[0].s)); ;}
+#line 127 "ppparse.y"
+    { yyval.l = cb_text_list_add (NULL, yyvsp[0].s); ;}
     break;
 
   case 30:
-#line 117 "ppparse.y"
+#line 129 "ppparse.y"
     {
-    (yyval.l) = cb_text_list_add ((yyvsp[-2].l), " ");
-    (yyval.l) = cb_text_list_add ((yyval.l), "IN");
-    (yyval.l) = cb_text_list_add ((yyval.l), " ");
-    (yyval.l) = cb_text_list_add ((yyval.l), (yyvsp[0].s));
+	yyval.l = cb_text_list_add (yyvsp[-2].l, " ");
+	yyval.l = cb_text_list_add (yyval.l, "IN");
+	yyval.l = cb_text_list_add (yyval.l, " ");
+	yyval.l = cb_text_list_add (yyval.l, yyvsp[0].s);
   ;}
     break;
 
   case 31:
-#line 124 "ppparse.y"
+#line 136 "ppparse.y"
     {
-    (yyval.l) = cb_text_list_add ((yyvsp[-2].l), " ");
-    (yyval.l) = cb_text_list_add ((yyval.l), "OF");
-    (yyval.l) = cb_text_list_add ((yyval.l), " ");
-    (yyval.l) = cb_text_list_add ((yyval.l), (yyvsp[0].s));
+	yyval.l = cb_text_list_add (yyvsp[-2].l, " ");
+	yyval.l = cb_text_list_add (yyval.l, "OF");
+	yyval.l = cb_text_list_add (yyval.l, " ");
+	yyval.l = cb_text_list_add (yyval.l, yyvsp[0].s);
   ;}
     break;
 
   case 32:
-#line 131 "ppparse.y"
+#line 143 "ppparse.y"
     {
-    struct cb_text_list *l;
-    (yyval.l) = cb_text_list_add ((yyvsp[-3].l), " ");
-    (yyval.l) = cb_text_list_add ((yyval.l), "(");
-    (yyvsp[-1].l) = cb_text_list_add ((yyvsp[-1].l), ")");
-    for (l = (yyval.l); l->next; l = l->next);
-    l->next = (yyvsp[-1].l);
+	struct cb_text_list *l;
+
+	yyval.l = cb_text_list_add (yyvsp[-3].l, " ");
+	yyval.l = cb_text_list_add (yyval.l, "(");
+	yyvsp[-1].l = cb_text_list_add (yyvsp[-1].l, ")");
+	for (l = yyval.l; l->next; l = l->next);
+	l->next = yyvsp[-1].l;
   ;}
     break;
 
   case 33:
-#line 141 "ppparse.y"
-    { (yyval.l) = cb_text_list_add (NULL, (yyvsp[0].s)); ;}
+#line 155 "ppparse.y"
+    { yyval.l = cb_text_list_add (NULL, yyvsp[0].s); ;}
     break;
 
   case 34:
-#line 143 "ppparse.y"
+#line 157 "ppparse.y"
     {
-    (yyval.l) = cb_text_list_add ((yyvsp[-1].l), " ");
-    (yyval.l) = cb_text_list_add ((yyval.l), (yyvsp[0].s));
+	yyval.l = cb_text_list_add (yyvsp[-1].l, " ");
+	yyval.l = cb_text_list_add (yyval.l, yyvsp[0].s);
   ;}
     break;
 
 
     }
 
-/* Line 1037 of yacc.c.  */
-#line 1260 "ppparse.c"
+/* Line 991 of yacc.c.  */
+#line 1229 "ppparse.c"
 
   yyvsp -= yylen;
   yyssp -= yylen;
@@ -1297,33 +1267,18 @@ yyerrlab:
 	{
 	  YYSIZE_T yysize = 0;
 	  int yytype = YYTRANSLATE (yychar);
-	  const char* yyprefix;
 	  char *yymsg;
-	  int yyx;
+	  int yyx, yycount;
 
+	  yycount = 0;
 	  /* Start YYX at -YYN if negative to avoid negative indexes in
 	     YYCHECK.  */
-	  int yyxbegin = yyn < 0 ? -yyn : 0;
-
-	  /* Stay within bounds of both yycheck and yytname.  */
-	  int yychecklim = YYLAST - yyn;
-	  int yyxend = yychecklim < YYNTOKENS ? yychecklim : YYNTOKENS;
-	  int yycount = 0;
-
-	  yyprefix = ", expecting ";
-	  for (yyx = yyxbegin; yyx < yyxend; ++yyx)
+	  for (yyx = yyn < 0 ? -yyn : 0;
+	       yyx < (int) (sizeof (yytname) / sizeof (char *)); yyx++)
 	    if (yycheck[yyx + yyn] == yyx && yyx != YYTERROR)
-	      {
-		yysize += yystrlen (yyprefix) + yystrlen (yytname [yyx]);
-		yycount += 1;
-		if (yycount == 5)
-		  {
-		    yysize = 0;
-		    break;
-		  }
-	      }
-	  yysize += (sizeof ("syntax error, unexpected ")
-		     + yystrlen (yytname[yytype]));
+	      yysize += yystrlen (yytname[yyx]) + 15, yycount++;
+	  yysize += yystrlen ("syntax error, unexpected ") + 1;
+	  yysize += yystrlen (yytname[yytype]);
 	  yymsg = (char *) YYSTACK_ALLOC (yysize);
 	  if (yymsg != 0)
 	    {
@@ -1332,13 +1287,16 @@ yyerrlab:
 
 	      if (yycount < 5)
 		{
-		  yyprefix = ", expecting ";
-		  for (yyx = yyxbegin; yyx < yyxend; ++yyx)
+		  yycount = 0;
+		  for (yyx = yyn < 0 ? -yyn : 0;
+		       yyx < (int) (sizeof (yytname) / sizeof (char *));
+		       yyx++)
 		    if (yycheck[yyx + yyn] == yyx && yyx != YYTERROR)
 		      {
-			yyp = yystpcpy (yyp, yyprefix);
+			const char *yyq = ! yycount ? ", expecting " : " or ";
+			yyp = yystpcpy (yyp, yyq);
 			yyp = yystpcpy (yyp, yytname[yyx]);
-			yyprefix = " or ";
+			yycount++;
 		      }
 		}
 	      yyerror (yymsg);
@@ -1356,58 +1314,55 @@ yyerrlab:
 
   if (yyerrstatus == 3)
     {
-      /* If just tried and failed to reuse look-ahead token after an
+      /* If just tried and failed to reuse lookahead token after an
 	 error, discard it.  */
 
-      if (yychar <= YYEOF)
+      /* Return failure if at end of input.  */
+      if (yychar == YYEOF)
         {
-          /* If at end of input, pop the error token,
-	     then the rest of the stack, then return failure.  */
-	  if (yychar == YYEOF)
-	     for (;;)
-	       {
-
-		 YYPOPSTACK;
-		 if (yyssp == yyss)
-		   YYABORT;
-		 yydestruct ("Error: popping",
-                             yystos[*yyssp], yyvsp);
-	       }
+	  /* Pop the error token.  */
+          YYPOPSTACK;
+	  /* Pop the rest of the stack.  */
+	  while (yyss < yyssp)
+	    {
+	      YYDSYMPRINTF ("Error: popping", yystos[*yyssp], yyvsp, yylsp);
+	      yydestruct (yystos[*yyssp], yyvsp);
+	      YYPOPSTACK;
+	    }
+	  YYABORT;
         }
-      else
-	{
-	  yydestruct ("Error: discarding", yytoken, &yylval);
-	  yychar = YYEMPTY;
-	}
+
+      YYDSYMPRINTF ("Error: discarding", yytoken, &yylval, &yylloc);
+      yydestruct (yytoken, &yylval);
+      yychar = YYEMPTY;
+
     }
 
-  /* Else will try to reuse look-ahead token after shifting the error
+  /* Else will try to reuse lookahead token after shifting the error
      token.  */
-  goto yyerrlab1;
+  goto yyerrlab2;
 
 
-/*---------------------------------------------------.
-| yyerrorlab -- error raised explicitly by YYERROR.  |
-`---------------------------------------------------*/
-yyerrorlab:
+/*----------------------------------------------------.
+| yyerrlab1 -- error raised explicitly by an action.  |
+`----------------------------------------------------*/
+yyerrlab1:
 
-#ifdef __GNUC__
-  /* Pacify GCC when the user code never invokes YYERROR and the label
-     yyerrorlab therefore never appears in user code.  */
-  if (0)
-     goto yyerrorlab;
+  /* Suppress GCC warning that yyerrlab1 is unused when no action
+     invokes YYERROR.  */
+#if defined (__GNUC_MINOR__) && 2093 <= (__GNUC__ * 1000 + __GNUC_MINOR__) \
+    && !defined __cplusplus
+  __attribute__ ((__unused__))
 #endif
 
-yyvsp -= yylen;
-  yyssp -= yylen;
-  yystate = *yyssp;
-  goto yyerrlab1;
+
+  goto yyerrlab2;
 
 
-/*-------------------------------------------------------------.
-| yyerrlab1 -- common code for both syntax error and YYERROR.  |
-`-------------------------------------------------------------*/
-yyerrlab1:
+/*---------------------------------------------------------------.
+| yyerrlab2 -- pop states until the error token can be shifted.  |
+`---------------------------------------------------------------*/
+yyerrlab2:
   yyerrstatus = 3;	/* Each real token shifted decrements this.  */
 
   for (;;)
@@ -1428,22 +1383,22 @@ yyerrlab1:
       if (yyssp == yyss)
 	YYABORT;
 
+      YYDSYMPRINTF ("Error: popping", yystos[*yyssp], yyvsp, yylsp);
+      yydestruct (yystos[yystate], yyvsp);
+      yyvsp--;
+      yystate = *--yyssp;
 
-      yydestruct ("Error: popping", yystos[yystate], yyvsp);
-      YYPOPSTACK;
-      yystate = *yyssp;
       YY_STACK_PRINT (yyss, yyssp);
     }
 
   if (yyn == YYFINAL)
     YYACCEPT;
 
+  YYDPRINTF ((stderr, "Shifting error token, "));
+
   *++yyvsp = yylval;
 
 
-  /* Shift the error token. */
-  YY_SYMBOL_PRINT ("Shifting", yystos[yyn], yyvsp, yylsp);
-
   yystate = yyn;
   goto yynewstate;
 
@@ -1459,9 +1414,6 @@ yyacceptlab:
 | yyabortlab -- YYABORT comes here.  |
 `-----------------------------------*/
 yyabortlab:
-  yydestruct ("Error: discarding lookahead",
-              yytoken, &yylval);
-  yychar = YYEMPTY;
   yyresult = 1;
   goto yyreturn;
 
@@ -1484,18 +1436,17 @@ yyreturn:
 }
 
 
-#line 152 "ppparse.y"
+#line 167 "ppparse.y"
 
 static char *
 fix_filename (char *name)
 {
-  /* remove quotation form alphanumeric literals */
-  if (name[0] == '\'' || name[0] == '\"')
-    {
-      name++;
-      name[strlen (name) - 1] = 0;
-    }
-  return name;
+	/* remove quotation form alphanumeric literals */
+	if (name[0] == '\'' || name[0] == '\"') {
+		name++;
+		name[strlen (name) - 1] = 0;
+	}
+	return name;
 }
 
 static struct cb_replace_list *
@@ -1503,18 +1454,18 @@ cb_replace_list_add (struct cb_replace_list *list,
 		     struct cb_text_list *old_text,
 		     struct cb_text_list *new_text)
 {
-  struct cb_replace_list *p = malloc (sizeof (struct cb_replace_list));
-  p->old_text = old_text;
-  p->new_text = new_text;
-  p->next = NULL;
-  if (!list)
-    return p;
-  else
-    {
-      struct cb_replace_list *l;
-      for (l = list; l->next; l = l->next);
-      l->next = p;
-      return list;
-    }
+	struct cb_replace_list *p = cobc_malloc (sizeof (struct cb_replace_list));
+	struct cb_replace_list *l;
+
+	p->old_text = old_text;
+	p->new_text = new_text;
+	p->next = NULL;
+	if (!list) {
+		return p;
+	} else {
+		for (l = list; l->next; l = l->next) ;
+		l->next = p;
+		return list;
+	}
 }
 
